@@ -180,9 +180,11 @@ function add($msg, $context=null) {
           $translation = $msg;
       }
       else {
-        fwrite(STDERR, "\"$msg\"\n\n => Please enter translated string (or 'c' to copy original message, leave empty to pass) : ");
+        fwrite(STDERR, "\"$msg\"\n\n => Please enter translated string (or 'c' to copy original message, 'i' to ignore this message, leave empty to pass) : ");
         $in = trim(fgets(STDIN));
         if ($in) {
+          if ($in=="i")
+            return True;
           if ($in=="c")
             $translation = $msg;
           else
@@ -247,6 +249,7 @@ if (!in_array('config', $withouts) && (!$only || $only == 'config')) {
     addFromLSconfig("ldap_servers.$ldap_server_id.recoverPassword.newPasswordMail.subject");
     addFromLSconfig("ldap_servers.$ldap_server_id.recoverPassword.newPasswordMail.msg");
     addFromLSconfig("ldap_servers.$ldap_server_id.subDn.*", 'key', array("LSobject"));
+    addFromLSconfig("ldap_servers.$ldap_server_id.LSprofiles.*.label");
 
     // LSaccess
     foreach (LSconfig :: get("ldap_servers.$ldap_server_id.LSaccess", array()) as $LSobject) {
