@@ -49,11 +49,12 @@ $GLOBALS['LSconfig'] = array(
       ),
 /*
       'LSauth' => array (
-        'method' => 'HTTP'
+        'method' => 'CAS'
       ),
 */
       'LSprofiles' => array (
         'admin' => array (
+          'label' => 'Administrator',
           'o=ls' => array (
             'uid=eeggs,ou=people,o=ls' => NULL
           ),
@@ -65,6 +66,7 @@ $GLOBALS['LSconfig'] = array(
           )
         ),
         'godfather' => array (
+          'label' => 'Godfather',
           'LSobjects' => array (
             'LSpeople' => array (
               'attr' => 'lsGodfatherDn',
@@ -210,8 +212,9 @@ $GLOBALS['LSlog']['handlers'] = array (
 $GLOBALS['LSlog']['level'] = 'DEBUG';
 $GLOBALS['LSlog']['enable'] = true;
 
-define('NB_LSOBJECT_LIST',20);
+define('NB_LSOBJECT_LIST',30);
 define('NB_LSOBJECT_LIST_SELECT',11);
+$GLOBALS['NB_LSOBJECT_LIST_CHOICES'] = array(30, 60, 100);
 
 define('MAX_SEND_FILE_SIZE',2000000);
 
