@@ -1,18 +1,18 @@
 <?php
-/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-07-01 18:10:03
+/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-09-30 13:14:17
   from "ls:viewSearch.tpl" */
 
 /* @var Smarty_Internal_Template $_smarty_tpl */
 if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
   'version' => '3.1.31',
-  'unifunc' => 'content_5d1a305b95d1c1_96543012',
+  'unifunc' => 'content_5d91e389aa6165_27599916',
   'has_nocache_code' => false,
   'file_dependency' => 
   array (
     '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
     array (
       0 => 'ls:viewSearch.tpl',
-      1 => 1559564613,
+      1 => 1567589000,
       2 => 'ls',
     ),
   ),
@@ -22,7 +22,7 @@ if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
     'ls:bottom.tpl' => 1,
   ),
 ),false)) {
-function content_5d1a305b95d1c1_96543012 (Smarty_Internal_Template $_smarty_tpl) {
+function content_5d91e389aa6165_27599916 (Smarty_Internal_Template $_smarty_tpl) {
 if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
 if (!is_callable('smarty_function_cycle')) require_once '/usr/share/php/smarty3/plugins/function.cycle.php';
 $_smarty_tpl->_subTemplateRender('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
@@ -255,8 +255,38 @@ $_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
 ?>
 
 </table>
+
 <span id='LSobject_list_nbresult'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_total, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 </span>
+<?php if (!empty($_smarty_tpl->tpl_vars['page']->value['list'])) {?>
+  <p class='LSobject-list-nb-by-page'>
+    <?php echo LStemplate_smarty_tr(array('msg'=>'Nb / page :'),$_smarty_tpl);?>
+
+    <?php
+$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSsearch']->value->getParam('nbObjectsByPageChoices'), 'choice');
+if ($_from !== null) {
+foreach ($_from as $_smarty_tpl->tpl_vars['choice']->value) {
+?>
+      <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->getParam('nbObjectsByPage') == $_smarty_tpl->tpl_vars['choice']->value) {?>
+        <strong><a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
+&amp;nbObjectsByPage=<?php echo $_smarty_tpl->tpl_vars['choice']->value;?>
+'  class='LSobject-list-nb-by-page'><?php echo $_smarty_tpl->tpl_vars['choice']->value;?>
+</a></strong>
+      <?php } else { ?>
+        <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
+&amp;nbObjectsByPage=<?php echo $_smarty_tpl->tpl_vars['choice']->value;?>
+'  class='LSobject-list-nb-by-page'><?php echo $_smarty_tpl->tpl_vars['choice']->value;?>
+</a>
+      <?php }?>
+    <?php
+}
+}
+$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
+?>
+
+  </p>
+<?php }?>
+
 <?php if ($_smarty_tpl->tpl_vars['page']->value['nbPages'] > 1) {?>
   <p class='LSobject-list-page'>
     
